@@ -1,4 +1,6 @@
+from importlib import import_module
 from tkinter.ttk import Frame
+from .ttk import CommonUIComponents
 
 class BaseTab(Frame):
    def __init__(self, master = None, **kw):
@@ -14,17 +16,29 @@ class BaseTab(Frame):
    def onDeleteWindow(self):
       pass
    
+   def _getValue(self, *keys):
+      proxy = self._ui
+      
+      for key in keys:
+         proxy = proxy[key]
+      
+      return proxy.value.value.get()
+   
    def _inflate(self, config):
       self._config = config
       
       if "ui" in self._config:
-         from commonuicomponents import CommonUIComponents
-         
          self._ui = CommonUIComponents.inflate(self._frame, self._config)
-   
-   @staticmethod
-   def load(notebook, wholeConfig, **baseTabKw):
-      from importlib import import_module
+
+
+class BaseTabLoader:
+   def load(self, notebook, wholeConfig, **baseTabKw):
+      self.__notebook = notebook
+      self.__wholeConfig = wholeConfig
+      
+      notebook.bind("<<NotebookTabChanged>>", self._onTabChanged)
+      
+      selectedIndex = wholeConfig.get("selectedIndex", 0)
       
       tabs = dict()
       tabsDir = wholeConfig["tabsDir"]
@@ -39,4 +53,9 @@ class BaseTab(Frame):
          
          notebook.add(tab, text = tab.caption)
       
+      notebook.select(selectedIndex)
+      
       return tabs
+   
+   def _onTabChanged(self, event):
+      self.__wholeConfig["selectedIndex"] = self.__notebook.index(self.__notebook.select())
